==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/ie/v20200304/models/Denoise.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ie.v20200304.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Denoise extends AbstractModel{

    /**
    * 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
    */
    @SerializedName("Type")
    @Expose
    private String Type;

    /**
     * Get 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak 
     * @return Type 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
     */
    public String getType() {
        return this.Type;
    }

    /**
     * Set 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
     * @param Type 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
     */
    public void setType(String Type) {
        this.Type = Type;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Type", this.Type);

    }
}

==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/ie/v20200304/models/Denoise.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ie.v20200304.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Denoise extends AbstractModel{

    /**
    * 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
    */
    @SerializedName("Type")
    @Expose
    private String Type;

    /**
     * Get 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak 
     * @return Type 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
     */
    public String getType() {
        return this.Type;
    }

    /**
     * Set 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
     * @param Type 音频降噪强度，可选项：
1. weak
2.normal，
3.strong
默认为weak
     */
    public void setType(String Type) {
        this.Type = Type;
    }

    public Denoise() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public Denoise(Denoise source) {
        if (source.Type != null) {
            this.Type = new String(source.Type);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Type", this.Type);

    }
}
